<?php

declare(strict_types=1);

namespace PrestaShop\Module\ConotoxiaPay\Configure;

use PrestaShop\Module\ConotoxiaPay\Definitions;
use PrestaShop\PrestaShop\Adapter\Entity\Configuration;
use PrestaShop\PrestaShop\Adapter\Entity\Language;
use PrestaShop\PrestaShop\Adapter\Entity\OrderState;
use PrestaShop\PrestaShop\Adapter\Entity\Tools;

/**
 * Class responsible for the configurations needed during installation/uninstallation/use of the module.
 */
class Configurator
{
    /**
     * Adds Conotoxia Pay new payment status if not exist
     *
     * @return boolean
     * @throws \PrestaShopDatabaseException
     * @throws \PrestaShopException
     */
    public static function addOrderWaitingStatus(): bool
    {
        if (Configuration::get(Definitions::WAITING_STATUS)) {
            return true;
        }

        $newOrderState = new OrderState();
        $newOrderState->name = array();
        foreach (Language::getLanguages() as $language) {
            if (Tools::strtolower($language['iso_code']) === 'pl') {
                $newOrderState->name[$language['id_lang']] = 'Oczekuje na potwierdzenie płatności z Cinkciarz Pay';
            } else {
                $newOrderState->name[$language['id_lang']] = 'Awaiting for Conotoxia Pay confirmation';
            }
        }
        $newOrderState->module_name = Definitions::MODULE_NAME;
        $newOrderState->send_email = false;
        $newOrderState->invoice = false;
        $newOrderState->unremovable = false;
        $newOrderState->color = '#4169E1';
        if (!$newOrderState->add()) {
            return false;
        }
        $stateId = $newOrderState->id;

        if ($stateId === false) {
            return false;
        }
        self::setWaitingStatus($stateId);
        self::copyStatusImage($stateId);
        return true;
    }

    /**
     * Removes Conotoxia Pay waiting payment status
     *
     * @return bool
     * @throws \PrestaShopException
     */
    public static function removeOrderWaitingStatus()
    {
        if (Configuration::get(Definitions::WAITING_STATUS)) {
            $orderState = new OrderState(self::getWaitingStatus());
            $orderState->delete();
        }
        return true;
    }

    /**
     * Get an id of payment waiting status
     * @return int
     */
    public static function getWaitingStatus()
    {
        return (int)Configuration::get(Definitions::WAITING_STATUS);
    }

    /**
     * Set an id of payment waiting status
     *
     * @param int $waitingStatus Id of payment waiting status
     * @return bool
     */
    public static function setWaitingStatus($waitingStatus)
    {
        return Configuration::updateValue(Definitions::WAITING_STATUS, (int)$waitingStatus);
    }

    /**
     * Copies the image from 'bankwire' to the new destination
     * @param string $dest name of the new image file
     * @return bool
     */
    private static function copyStatusImage($dest)
    {
        $dir = _PS_ORDER_STATE_IMG_DIR_;
        return copy($dir . _PS_OS_BANKWIRE_ . '.gif', $dir . $dest . '.gif');
    }
}